# Module to use python with SAP GUI RPA

Please find repository with my module which gives possibility to use SAP GUI scripting.
It can help you automate your SAP activities using its RPA.  

# Prerequisite:
pip install pywin32
pip install pandas
pip install sapgui




